==> gcloud-jyxc-app-1.2.2.tgz: package/main.js <==
import Vue from 'vue'
import App from './App'
import store from './src/store'

Vue.config.productionTip = false

import {
	router,
	RouterMount
} from 'gcloud-oauth-app/src/router/index.js' //路径换成自己的
import "gcloud-oauth-app/src/router/permission"
Vue.use(router)

import uView from 'uview-ui'
Vue.use(uView)

import config from 'gcloud-core-app/src/core/config.js'
import {
	tokenOpts,
	tokenStreamOpts
} from 'gcloud-oauth-app/src/grpc/token'
import {
	oauthOpts
} from 'gcloud-oauth-app/src/grpc/oauth'

config.oauthOpts = oauthOpts;
config.baseOpts = tokenOpts;
config.baseStreamOpts = tokenStreamOpts;

const url = 'https://szxcapi.mlxcun.com'
config.baseUrl = url;
config.oauthUrl = url;
// const url = 'http://10.10.22.31:8089' //测试环境
// const url = 'http://192.168.2.126:8199' //本地环境
config.baseUrl = 'http://192.168.2.46:8199';
config.oauthUrl = 'http://192.168.2.46:8199';
config.yktBaseUrl = 'https://ykt.sxnyy.cn:10005';
config.nbBaseUrl = 'https://nb.sxnyy.cn:8085';
// 图片下载地址
config.fileBaseUrl = url;
config.uploadFileBaseUrl = url + '/download/';

// config.uploadFileBaseUrl = 'http://10.10.22.31:8045' + '/download/';
// config.fileBaseUrl = 'http://10.10.22.31:8045'; //测试
// config.uploadFileBaseUrl = 'http://10.10.22.31:8045' + '/download/';
// config.fileBaseUrl = 'http://10.10.22.31:8045'; //测试



Vue.prototype.$config = config

console.log(config);

import GcloudJyxcApp from './src/gcloud/index.js'
Vue.use(GcloudJyxcApp, config)

import GcloudOAuth  from 'node_modules/gcloud-oauth-app/src/index.js'
Vue.use(GcloudOAuth,config);

import GcloudFile  from 'node_modules/gcloud-file-app/src/index.js'
Vue.use(GcloudFile,config);


//顶部导航
import tabLayout from 'uview-ui/components/u-navbar/u-navbar.vue'
Vue.component('tab-layout',tabLayout)


import cuCustom from 'node_modules/gcloud-oauth-app/components/colorui/components/cu-custom.vue'
Vue.component('cu-custom',cuCustom)

App.mpType = 'app'

// 图片上传
import gcloudImageUpload from 'gcloud-file-app/pages/gcloud-image-upload/src/main.vue'
Vue.component('gcloud-image-upload',gcloudImageUpload)

const app = new Vue({
    ...App,
	store
})
// app.$mount()
//v1.3.5起 H5端 你应该去除原有的app.$mount();使用路由自带的渲染方式
// #ifdef H5
RouterMount(app, router, '#app')
// #endif

// #ifndef H5
app.$mount(); //为了兼容小程序及app端必须这样写才有效果
// #endif

==> gcloud-jyxc-app-1.2.11.tgz: package/main.js <==
import Vue from 'vue'
import App from './App'

Vue.config.productionTip = false
App.mpType = 'app'

import {
	router,
	RouterMount
} from 'gcloud-oauth-app/src/router/index.js' //路径换成自己的
import "gcloud-oauth-app/src/router/permission"
Vue.use(router)


// 引入全局uView
import uView from 'uview-ui';
Vue.use(uView);

import store from './src/store'   //引入vuex
Vue.prototype.$store = store; // 挂载vuex
store.dispatch('settings/title', "乡村超市");

import 'gcloud-oauth-app/src/utils/permit';

import config from 'gcloud-core-app/src/core/config.js'
import {tokenOpts,tokenStreamOpts} from 'gcloud-oauth-app/src/grpc/token'
import {oauthOpts} from 'gcloud-oauth-app/src/grpc/oauth'
config.oauthOpts = oauthOpts;
config.baseOpts = tokenOpts;
config.baseStreamOpts = tokenStreamOpts;
config.nbBaseUrl = 'https://nb.sxnyy.cn:8085';


// const url = 'http://10.10.22.31:8089' //测试环境
const url = 'https://szxcapi.mlxcun.com'
config.baseUrl = url;
config.oauthUrl = url;
// const url = 'http://10.10.22.31:8089' //测试环境
// const url = 'http://192.168.2.126:8199' //本地环境
// config.baseUrl = 'http://192.168.2.180:8199';
// config.oauthUrl = 'http://192.168.2.180:8199';
config.yktBaseUrl = 'https://ykt.sxnyy.cn:10005';
config.nbBaseUrl = 'https://nb.sxnyy.cn:8085';
// 图片下载地址
config.fileBaseUrl = url;
config.uploadFileBaseUrl = url + '/download/';

// config.uploadFileBaseUrl = 'http://10.10.22.31:8045' + '/download/';
// config.fileBaseUrl = 'http://10.10.22.31:8045'; //测试


Vue.prototype.$config = config

console.log(config);


import GcloudOAuth  from 'gcloud-oauth-app/src/index.js'
Vue.use(GcloudOAuth, config)

import GcloudJyxcApp from './src/gcloud/index.js'
Vue.use(GcloudJyxcApp, config)

// 文件
import GcloudFile from 'gcloud-file-app/src/index.js';
Vue.use(GcloudFile, config);

import gcloudUpload from 'gcloud-file-app/pages/gcloud-image-upload/src/main.vue';
Vue.component('gcloud-upload-file', gcloudUpload)


// //列表组件（包含多选框）
// import listCont from 'gcloud-xccs-app/components/szxc/listCont/listCont.vue';
// Vue.component('listCont',listCont)


// 图片上传
import gcloudImageUpload from 'gcloud-file-app/pages/gcloud-image-upload/src/main.vue'
Vue.component('gcloud-image-upload',gcloudImageUpload)


const app = new Vue({
	...App,
	store
})

//v1.3.5起 H5端 你应该去除原有的app.$mount();使用路由自带的渲染方式
// #ifdef H5
RouterMount(app, router, '#app')
// #endif

// #ifndef H5
app.$mount(); //为了兼容小程序及app端必须这样写才有效果
// #endif
